# Unofficial Python wrapper for PowerBI RestAPI

Important note: this software comes with no warranty and provided as is.

## Intro

This is an unofficial python wrapper around [PowerBI rest API][1]

It only wraps those functions that I needed for my projects.

Pull requests are welcome.

## Usage

for usage see [Usage.ipynb][2]

[1]: https://msdn.microsoft.com/en-us/library/mt147898.aspx
[2]: Usage.ipynb

